colors library

Module for defining colors used in the Celeryviz frontend.

This is work in progress, we have colours scattered in the codebase which needs to be brought here and managed properly.

Constants

backgroudColor → const Color