CeleryEventBase class

Implementers

Constructors

CeleryEventBase({required String hostname, required int utcoffset, required int pid, required int clock, required String uuid, required double timestamp, required String type, required double localReceived})
CeleryEventBase.fromJson(Map<String, dynamic> json)

Properties

clock int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostname String
getter/setter pair
localReceived double
getter/setter pair
pid int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp double
getter/setter pair
type String
getter/setter pair
utcoffset int
getter/setter pair
uuid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited