CeleryEventLog class

Represents the event where the task logs a message.

Inheritance

Constructors

CeleryEventLog({required String hostname, required int utcoffset, required int pid, required int clock, required String uuid, required double timestamp, required String type, required double localReceived, required String msg, required int levelno, required String pathname, required int lineno, required String name, required dynamic excInfo})
CeleryEventLog.fromJson(Map<String, dynamic> json)

Properties

clock int
getter/setter pairinherited
excInfo → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
hostname String
getter/setter pairinherited
levelno int
final
lineno int
final
localReceived double
getter/setter pairinherited
msg String
final
name String
final
pathname String
final
pid int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp double
getter/setter pairinherited
type String
getter/setter pairinherited
utcoffset int
getter/setter pairinherited
uuid String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited