CeleryEventSpawned class
Represents the event where the child task is spawned (received by worker).
- Inheritance
-
- Object
- CeleryEventBase
- CeleryEventSpawned
Constructors
Properties
- childId ↔ String
-
getter/setter pair
- clock ↔ int
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname ↔ String
-
getter/setter pairinherited
- localReceived ↔ double
-
getter/setter pairinherited
- pid ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ double
-
getter/setter pairinherited
- type ↔ String
-
getter/setter pairinherited
- utcoffset ↔ int
-
getter/setter pairinherited
- uuid ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited