PaneData class
Data class to store all the events in the pane.
It uses a Map to store the events for each task, where the key is the task id and the value is the TaskData for that task.
Constructors
- PaneData()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minTimestamp → double?
-
no setter
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited -
taskIds
→ List<
String> -
no setter
-
tasks
→ Map<
String, TaskData> -
final
Methods
-
addEvent(
Map< String, dynamic> eventJson) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited