TaskData class

Data class to store events for a single task.

It uses a SplayTreeMap to store the events in sorted order of their timestamps efficiently. Stores other information about the task in TaskInfo and assigns a random color to the task.

Constructors

TaskData({required String taskId})

Properties

color Color
final
endTimestamp double?
no setter
eventsList List<CeleryEventBase>
no setter
firstRenderTimestamp double
no setter
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp double?
no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
taskId String
final
taskInfo TaskInfo
final

Methods

addEvent(dynamic event) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited