TaskInfo class

Data class which holds the information about a single task.

Constructors

TaskInfo({double? etaTimestamp, double? startTimestamp, double? endTimestamp, String? taskId})

Properties

args String?
getter/setter pair
endTimestamp double?
getter/setter pair
etaTimestamp double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kwargs String?
getter/setter pair
name String?
getter/setter pair
result String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp double?
getter/setter pair
status TaskStatus
getter/setter pair
taskId String?
getter/setter pair

Methods

extractData(CeleryEventBase event) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited