NDJsonDataSource class
Data source which reads events from an NDJson file.
- Inheritance
-
- Object
- DataSource
- NDJsonDataSource
Constructors
- NDJsonDataSource({required String filePath})
Properties
- dataSourceFailureMessage → String
-
no setteroverride
- filePath → String
-
The path to the NDJson file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
void onSetupComplete(), void onSetupFailed()) → Future -
override
-
start(
SendEventsToBloc sendEventsToBloc) → void -
override
-
stop(
) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited