QueriableDataSource class abstract

Data source which supports fetching historical events.

(To be used for the database based datasource)

Inheritance

Constructors

QueriableDataSource()

Properties

dataSourceFailureMessage String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seek(double timestamp) → void
setup(void onSetupComplete(), void onSetupFailed()) Future
inherited
start(SendEventsToBloc sendEventsToBloc) → void
inherited
stop() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited