SocketIODataSource class

Datasource which connects with (celeryiz backend) socket.io server to get realtime events.

Inheritance

Constructors

SocketIODataSource(String socketioServerLocation)

Properties

dataSourceFailureMessage String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketioServerLocation String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup(void onSetupComplete(), void onSetupFailed()) Future
override
start(SendEventsToBloc sendEventsToBloc) → void
override
stop() → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited