widgets/pane/panable_area/task_column library
The task column represents the Celery task and renders all its events.
Classes
- TaskColumn
- Manages the layout and rendering of the events of the celery task.
- TaskLine
- Draws the verticle line representing the task timeline. Also handles hover and tap events for the task.