widgets/pane/task_name_bar library

Houses the widgets needed to show the horizontal task name bar above the pane.

Classes

TaskNameBar
This widget is used to display the horizontal task name bar above the pane.
TaskNameBarItem
Widget for displaying task id in the task name bar.