models/event library
Classes for the celery task events.
Classes
- CeleryEventBase
- CeleryEventLog
- Represents the event where the task logs a message.
- CeleryEventScheduled
- Represents the event in the parent task for spawning a child task.
- CeleryEventSpawned
- Represents the event where the child task is spawned (received by worker).
- CeleryEventStarted
- Represents the event where the tas kstarts executing on the Celery worker.
- CeleryEventSucceeded
- Represents the event where the task succeeded.
Functions
-
getCeleryEventFromJson(
Map< String, dynamic> json) → CeleryEventBase - Factory method to create a CeleryEventBase or its subclasses from JSON.