services/data_source library
Data source which is used to load the data from the Celeryviz server.
Classes
- DataSource
- NDJsonDataSource
- Data source which reads events from an NDJson file.
- QueriableDataSource
- Data source which supports fetching historical events.
- SnapshotDataSource
- A datasource which loads all events during initialization and directly renders all the events. (No livestreaming or temporal replay)
- SocketIODataSource
- Datasource which connects with (celeryiz backend) socket.io server to get realtime events.
Typedefs
-
JsonObject
= Map<
String, dynamic> -
SendEventsToBloc
= void Function(List<
Map< events)String, dynamic> >