SnapshotDataSource class
A datasource which loads all events during initialization and directly renders all the events. (No livestreaming or temporal replay)
- Inheritance
-
- Object
- DataSource
- SnapshotDataSource
Constructors
-
SnapshotDataSource({required List<
Map< eventsJson})String, dynamic> >
Properties
- currentTimestamp → double
-
no setter
- dataSourceFailureMessage → String
-
no setterinherited
-
eventsJson
→ List<
Map< String, dynamic> > -
The events to be rendered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
void onSetupComplete(), void onSetupFailed()) → Future -
override
-
start(
SendEventsToBloc sendEventsToBloc) → void -
override
-
stop(
) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited