NavigationTransformationController class
Transformation controller which supports smooth animations when navigating the using navigate.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
Matrix4> - TransformationController
- NavigationTransformationController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- maxX ↔ double
-
getter/setter pair
- maxY ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ Matrix4
-
The current value stored in this notifier.
getter/setter pairinherited
- vsync → TickerProvider
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toScene(
Offset viewportPoint) → Offset -
Return the scene point at the given viewport point.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateBounds(
double newX, double newY) → void - Updates the boundries for the navigate method.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited